@@ -2,17 +2,27 @@
 
 namespace Wallabag\CoreBundle\Repository;
 
-use Doctrine\ORM\EntityRepository;
+use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
 use Doctrine\ORM\NoResultException;
 use Doctrine\ORM\QueryBuilder;
+use Doctrine\Persistence\ManagerRegistry;
 use Pagerfanta\Doctrine\ORM\QueryAdapter as DoctrineORMAdapter;
 use Pagerfanta\Pagerfanta;
 use Wallabag\CoreBundle\Entity\Entry;
 use Wallabag\CoreBundle\Entity\Tag;
 use Wallabag\CoreBundle\Helper\UrlHasher;
 
-class EntryRepository extends EntityRepository
+/**
+ * @method Entry[]    findById(int $id)
+ * @method Entry|null findOneByUser(int $userId)
+ */
+class EntryRepository extends ServiceEntityRepository
 {
+    public function __construct(ManagerRegistry $registry)
+    {
+        parent::__construct($registry, Entry::class);
+    }
+
     /**
      * Retrieves all entries for a user.
      *
@@ -373,7 +383,7 @@ class EntryRepository extends EntityRepository
      * Remove tags from all user entries.
      *
      * @param int        $userId
-     * @param Array<Tag> $tags
+     * @param array<Tag> $tags
      */
     public function removeTags($userId, $tags)
     {
